# Bankruptcy Appellate Panel for the Ninth Circuit

Reminder: For all BAP cases filed on or after March 31, 2010, electronic filing using the BAP's Case Management/Electronic Case Filing (CM/ECF) system is mandatory for all attorneys, unless they are granted an exemption by BAP from using the CM/ECF system. Please review the contents of this website for further information.
Annual Hearing Calendar
Court Information & Monthly Calendars
Electronic Case Files (ECF)
Litigants Manual (PDF file)
Local Rules (PDF file)
Notices & Forms
PACER
Seminar Disclosure System

Search
by Opinion type: |  |  |  |
by Debtor: |  |  |  |
by BAP Number: |  |  |  |
by Date Filed (mm/dd/yyyy): |  |  |  |
Search type:

Results: 1 - 50 of 1,028 |
Pages: |<< << | 1, 2, 3, 4, ... | >> >>|
| Page size:

loading data...

Debtor | Document Type | BAP Number | Date Filed
--- | --- | --- | ---
KOKO SARKIS BABIAN | Unpublished Opinion | CC-12-1226-BePaMk | 01/04/2013
CONRAD J. KUIKEN, JR. | Published Opinion | SC-12-1218-JuMkPa | 01/04/2013
BETSEY WARREN LEBBOS | Unpublished Opinion | EC-11-1735-KiDJu | 12/31/2012
OSCAR TREJO | Unpublished Opinion | NC-11-1652-HPaMk | 12/20/2012
HERBERT M. ZUKERKORN; JENNIFER ZUKERKORN | Published Opinion | NC-11-1506-JuKiJo | 12/19/2012
MAURA SANTANA and TEODORO SANTANA | Unpublished Opinion | CC-12-1186-HaMkH | 12/19/2012
E. DANIEL BORS, III | Unpublished Opinion | CC-12-1214-KiDH | 12/17/2012
TIMOTHY L. BLIXSETH | Published Opinion | NV-11-1305-PaJuH | 12/17/2012
JOSE J. HERNANDEZ | Published Opinion | SC-12-1209-JuMkPa; SC-12-1217-JuMkPa (consolidated appeals) | 12/14/2012
RAUL MACHUCA, JR. | Published Opinion | NC-12-1081-MkHPa | 12/14/2012
WILEHARDA KILIAN MBUNDA | Published Opinion | NC-11-1653-MkHPa | 12/14/2012
ASATOUR BAGHDASARIAN | Unpublished Opinion | CC-11-1568-KiDH | 12/14/2012
GENNADY TIKHONOV and ALBINA TIKHONOV | Unpublished Opinion | CC-11-1698-MkBePa | 12/14/2012
MARYETTA C. MARKS | Unpublished Opinion | CC-12-1140-KiDH | 12/14/2012
DANA PAUL FOSTER and CHERYL DEANN FOSTER | Unpublished Opinion | EC-11-1706-KiDJu | 12/14/2012
ANDREA R. BECKFORD | Unpublished Opinion | CC-12-1131-PaMkBe | 12/14/2012
ALVIN LABOSTRIE and SANDRA LABOSTRIE | Unpublished Opinion | CC-12-1164-PaMkBe | 12/14/2012
PASCAL JEAN-FRANCOIS BESSET | Unpublished Opinion | SC-12-1062-JuMkPa | 12/14/2012
MIGUEL LEON; GREGORY LEE | Unpublished Opinion | CC-12-1150-MkBePa | 12/14/2012
MICHAEL RENE RODARTE | Unpublished Opinion | CC-12-1276-HKiD | 12/06/2012
TINA CHI HOUNG | Unpublished Opinion | CC-12-1208-DHKi | 12/06/2012
MARCOS ALONZO NIETO and HILDY JEAN ORTIZ | Unpublished Opinion | EC-11-1607-DJuKi; EC-11-1619-DJuKi; EC-11-1643-DJuKi; EC-12-1015-DJuKi | 12/06/2012
HARVEY P. MICKELSEN and STEPHANIE B. MICKELSEN | Unpublished Opinion | EC-11-1613-DJuKi; EC-12-1017-DJuKi; EC-12-1018-DJuKi; EC-12-1019-DJuKi | 12/06/2012
BEN LEANDO DYE and KAELYN MARIE DYE | Unpublished Opinion | EC-11-1641-DJuKi; EC-12-1016-DJuKi | 12/06/2012
FERDINAND GERTES and EMMA R. DUTRO | Unpublished Opinion | CC-12-1257-HKiD | 12/05/2012
FIRST STREET HOLDINGS NV, LLC, et al. | Unpublished Opinion | NC-11-1729-MkHPa | 12/05/2012
SUNG HO CHA and YOUHNG LIM PARK | Published Opinion | NC-11-1579-JoJuKi | 12/05/2012
ROBERT HARRIS | Unpublished Opinion | CC-11-1600-DHKi | 11/29/2012
MARCELO BRITTO GOMEZ | Unpublished Opinion | CC-12-1144-DHKi | 11/28/2012
PATRICIA NIETO | Unpublished Opinion | NV-11-1124-JuPaD | 11/28/2012
STEPHANIE A. DIENER | Published Opinion | CC-12-1093-KiNoPa | 11/21/2012
KENNETH BRUCE TISHGART and LORI ANNE TISHGART | Unpublished Opinion | NC-12-1160-PaMkH | 11/13/2012
JOSHUA P. PAGNINI and TENEIL A. PAGNINI | Unpublished Opinion | NC-12-1085-PaMkH | 11/13/2012
HARRY PALMER ALTICK | Unpublished Opinion | NC-12-1121-PaMkH | 11/13/2012
SAMAN HASNAIN | Unpublished Opinion | NC-11-1631-DJuKi | 11/09/2012
YONG LI | Unpublished Opinion | CC-11-1490-HTaMk | 11/07/2012
IMANI FE, LP, AKA Abs Bricker, LLC, AKA Abs Hollywood, LLC, AKA Abs Imani Fe, LLC, AKA Abs Magnolia, LLC, AKA Abs Mayer Bricker, | Unpublished Opinion | CC-12-1111-HHaMk | 11/07/2012
SMB GROUP, INC. | Unpublished Opinion | CC-11-1610-KiDMk | 11/07/2012
ANTONIA ALEMAN | Unpublished Opinion | CC-11-1410-HHaMk; CC-11-1423-HHaMk (Related Appeals) | 11/07/2012
ROBERT YATES JACKSON | Unpublished Opinion | NC-11-1683-HPaMk | 11/06/2012
PAUL DENBESTE and MELODY DENBESTE | Unpublished Opinion | NC-12-1087-HPaMk; NC-12-1180-HPaMk (Related Appeals) | 11/06/2012
JAMES LARRY SACCHERI and JUDITH ANNE SACCHERI | Unpublished Opinion | 12-1269-JuKiD | 11/01/2012
JERRY SLATES | Unpublished Opinion | EC-12-1168-KiDJu | 10/31/2012
MICHAEL WOOD | Unpublished Opinion | 12-1108-JuKiD | 10/31/2012
MICHAEL S. ZUCKERMAN | Unpublished Opinion | CC-11-1664-KiNoPa | 10/31/2012
JAMES F. BISHAY | Unpublished Opinion | CC-12-1143-TaMkH | 10/24/2012
PAULA MARIE OLIVER | Unpublished Opinion | CC-11-1482-PaKiRn | 10/23/2012
JOAN KATHLEEN GREEN | Unpublished Opinion | CC-11-1374-MkHHa | 10/15/2012
CHARLENE GRUNTZ | Unpublished Opinion | CC-11-1483-MkHTa | 10/15/2012
ANNA LEAFTY | Published Opinion | AZ-11-1491-JuBrD | 10/10/2012

Results: 1 - 50 of 1,028 |
Pages: |<< << | 1, 2, 3, 4, ... | >> >>|
| Page size:

- Judges
- Lawyer Representatives
- Court Statistics
- Judicial Vacancies
- Judicial Nominations
- Judicial Confirmations
- Judicial Misconduct
- Judgeship Opportunities
- Civil Jury Instructions
- Criminal Jury Instructions
- Pretrial Services
- Probation Services
- Employment

- Federal Judges
  Biographical Database
- Bankuptcy Appellate Panel

Site Map | Intranet (Judiciary Only) | COOP Staff Page | Seminar Disclosures | Judicial Misconduct |